@@ -13,7 +13,7 @@
 #' @param values (`character`)\cr specific values that should be counted.
 #' @param .stats (`character`)\cr statistics to select for the table.
 #'
-#'   Options are: ``r shQuote(get_stats("count_values"))``
+#'   Options are: ``r shQuote(get_stats("count_values"), type = "sh")``
 #'
 #' @note
 #' * For `factor` variables, `s_count_values` checks whether `values` are all included in the levels of `x`
@@ -110,22 +110,20 @@ s_count_values.logical <- function(x, values = TRUE, ...) {
 a_count_values <- function(x,
                            ...,
                            .stats = NULL,
+                           .stat_names = NULL,
                            .formats = NULL,
                            .labels = NULL,
                            .indent_mods = NULL) {
+  # Check for additional parameters to the statistics function
   dots_extra_args <- list(...)
+  extra_afun_params <- retrieve_extra_afun_params(names(dots_extra_args$.additional_fun_parameters))
+  dots_extra_args$.additional_fun_parameters <- NULL
 
   # Check for user-defined functions
   default_and_custom_stats_list <- .split_std_from_custom_stats(.stats)
-  .stats <- default_and_custom_stats_list$default_stats
+  .stats <- default_and_custom_stats_list$all_stats
   custom_stat_functions <- default_and_custom_stats_list$custom_stats
 
-  # Add extra parameters to the s_* function
-  extra_afun_params <- retrieve_extra_afun_params(
-    names(dots_extra_args$.additional_fun_parameters)
-  )
-  dots_extra_args$.additional_fun_parameters <- NULL
-
   # Main statistic calculations
   x_stats <- .apply_stat_functions(
     default_stat_fnc = s_count_values,
@@ -138,28 +136,26 @@ a_count_values <- function(x,
   )
 
   # Fill in formatting defaults
-  .stats <- c(
-    get_stats("analyze_vars_counts", stats_in = .stats),
-    names(custom_stat_functions) # Additional stats from custom functions
-  )
+  .stats <- get_stats("analyze_vars_counts", stats_in = .stats, custom_stats_in = names(custom_stat_functions))
   .formats <- get_formats_from_stats(.stats, .formats)
   .labels <- get_labels_from_stats(.stats, .labels)
   .indent_mods <- get_indents_from_stats(.stats, .indent_mods)
 
+  x_stats <- x_stats[.stats]
+
   # Auto format handling
-  .formats <- apply_auto_formatting(
-    .formats,
-    x_stats,
-    extra_afun_params$.df_row,
-    extra_afun_params$.var
-  )
+  .formats <- apply_auto_formatting(.formats, x_stats, extra_afun_params$.df_row, extra_afun_params$.var)
+
+  # Get and check statistical names
+  .stat_names <- get_stat_names(x_stats, .stat_names)
 
   in_rows(
-    .list = x_stats[.stats],
+    .list = x_stats,
     .formats = .formats,
     .names = names(.labels),
-    .labels = .labels,
-    .indent_mods = .indent_mods
+    .stat_names = .stat_names,
+    .labels = .labels %>% .unlist_keep_nulls(),
+    .indent_mods = .indent_mods %>% .unlist_keep_nulls()
   )
 }
 
@@ -188,17 +184,23 @@ count_values <- function(lyt,
                          ...,
                          table_names = vars,
                          .stats = "count_fraction",
+                         .stat_names = NULL,
                          .formats = c(count_fraction = "xx (xx.xx%)", count = "xx"),
                          .labels = c(count_fraction = paste(values, collapse = ", ")),
                          .indent_mods = NULL) {
-  # Process extra args
+  # Process standard extra arguments
   extra_args <- list(".stats" = .stats)
+  if (!is.null(.stat_names)) extra_args[[".stat_names"]] <- .stat_names
   if (!is.null(.formats)) extra_args[[".formats"]] <- .formats
   if (!is.null(.labels)) extra_args[[".labels"]] <- .labels
   if (!is.null(.indent_mods)) extra_args[[".indent_mods"]] <- .indent_mods
 
-  # Add additional arguments to the analysis function
-  extra_args <- c(extra_args, "na_rm" = na_rm, "values" = list(values), ...)
+  # Process additional arguments to the statistic function
+  extra_args <- c(
+    extra_args,
+    na_rm = na_rm, values = list(values),
+    ...
+  )
 
   # Adding additional info from layout to analysis function
   extra_args[[".additional_fun_parameters"]] <- get_additional_afun_params(add_alt_df = FALSE)
