@@ -173,47 +173,3 @@ h_logistic_mult_cont_df <- function(variables,
     )
   }
 }
-
-#' @describeIn h_response_biomarkers_subgroups Prepares a single sub-table given a `df_sub` containing
-#'   the results for a single biomarker.
-#'
-#' @param df (`data.frame`)\cr results for a single biomarker, as part of what is
-#'   returned by [extract_rsp_biomarkers()] (it needs a couple of columns which are
-#'   added by that high-level function relative to what is returned by [h_logistic_mult_cont_df()],
-#'   see the example).
-#'
-#' @return
-#' * `h_tab_rsp_one_biomarker()` returns an `rtables` table object with the given statistics arranged in columns.
-#'
-#' @examples
-#' # Starting from above `df`, zoom in on one biomarker and add required columns.
-#' df1 <- df[1, ]
-#' df1$subgroup <- "All patients"
-#' df1$row_type <- "content"
-#' df1$var <- "ALL"
-#' df1$var_label <- "All patients"
-#'
-#' h_tab_rsp_one_biomarker(
-#'   df1,
-#'   vars = c("n_tot", "n_rsp", "prop", "or", "ci", "pval")
-#' )
-#'
-#' @export
-h_tab_rsp_one_biomarker <- function(df,
-                                    vars,
-                                    na_str = default_na_str(),
-                                    .indent_mods = 0L) {
-  afuns <- a_response_subgroups(na_str = na_str)[vars]
-  colvars <- d_rsp_subgroups_colvars(
-    vars,
-    conf_level = df$conf_level[1],
-    method = df$pval_label[1]
-  )
-  h_tab_one_biomarker(
-    df = df,
-    afuns = afuns,
-    colvars = colvars,
-    na_str = na_str,
-    .indent_mods = .indent_mods
-  )
-}
