@@ -177,51 +177,3 @@ h_coxreg_mult_cont_df <- function(variables,
     )
   }
 }
-
-#' @describeIn h_survival_biomarkers_subgroups Prepares a single sub-table given a `df_sub` containing
-#'   the results for a single biomarker.
-#'
-#' @param df (`data.frame`)\cr results for a single biomarker, as part of what is
-#'   returned by [extract_survival_biomarkers()] (it needs a couple of columns which are
-#'   added by that high-level function relative to what is returned by [h_coxreg_mult_cont_df()],
-#'   see the example).
-#'
-#' @return
-#' * `h_tab_surv_one_biomarker()` returns an `rtables` table object with the given statistics arranged in columns.
-#'
-#' @examples
-#' # Starting from above `df`, zoom in on one biomarker and add required columns.
-#' df1 <- df[1, ]
-#' df1$subgroup <- "All patients"
-#' df1$row_type <- "content"
-#' df1$var <- "ALL"
-#' df1$var_label <- "All patients"
-#' h_tab_surv_one_biomarker(
-#'   df1,
-#'   vars = c("n_tot", "n_tot_events", "median", "hr", "ci", "pval"),
-#'   time_unit = "days"
-#' )
-#'
-#' @export
-h_tab_surv_one_biomarker <- function(df,
-                                     vars,
-                                     time_unit,
-                                     na_str = default_na_str(),
-                                     .indent_mods = 0L,
-                                     ...) {
-  afuns <- a_survival_subgroups(na_str = na_str)[vars]
-  colvars <- d_survival_subgroups_colvars(
-    vars,
-    conf_level = df$conf_level[1],
-    method = df$pval_label[1],
-    time_unit = time_unit
-  )
-  h_tab_one_biomarker(
-    df = df,
-    afuns = afuns,
-    colvars = colvars,
-    na_str = na_str,
-    .indent_mods = .indent_mods,
-    ...
-  )
-}
