@@ -354,7 +354,8 @@ tabulate_rsp_subgroups <- function(lyt,
       var = "row_type",
       split_fun = keep_split_levels("content"),
       nested = FALSE,
-      child_labels = "hidden"
+      child_labels = "hidden",
+      parent_name = "All Patients"
     )
     lyt_prop <- analyze_colvars(
       lyt = lyt_prop,
@@ -370,7 +371,8 @@ tabulate_rsp_subgroups <- function(lyt,
         var = "row_type",
         split_fun = keep_split_levels("analysis"),
         nested = FALSE,
-        child_labels = "hidden"
+        child_labels = "hidden",
+        parent_name = "analysis rows"
       )
       lyt_prop <- split_rows_by(lyt = lyt_prop, var = "var_label", nested = TRUE)
       lyt_prop <- analyze_colvars(
@@ -401,7 +403,8 @@ tabulate_rsp_subgroups <- function(lyt,
     var = "row_type",
     split_fun = keep_split_levels("content"),
     nested = FALSE,
-    child_labels = "hidden"
+    child_labels = "hidden",
+    parent_name = "All Patients"
   )
   lyt_or <- analyze_colvars(
     lyt = lyt_or,
@@ -418,7 +421,8 @@ tabulate_rsp_subgroups <- function(lyt,
       var = "row_type",
       split_fun = keep_split_levels("analysis"),
       nested = FALSE,
-      child_labels = "hidden"
+      child_labels = "hidden",
+      parent_name = "analysis rows"
     )
     lyt_or <- split_rows_by(lyt = lyt_or, var = "var_label", nested = TRUE)
     lyt_or <- analyze_colvars(
