@@ -5,7 +5,7 @@ testthat::test_that("h_count_cumulative works with healthy input and default arg
   result <- h_count_cumulative(
     x = x,
     threshold = 5,
-    .N_col = length(x)
+    denom = length(x)
   )
 
   res <- testthat::expect_silent(result)
@@ -22,8 +22,8 @@ testthat::test_that("h_count_cumulative works with customized arguments", {
     threshold = 5,
     lower_tail = FALSE,
     include_eq = FALSE,
-    na.rm = FALSE,
-    .N_col = length(x)
+    na_rm = FALSE,
+    denom = length(x)
   )
 
   res <- testthat::expect_silent(result)
@@ -54,7 +54,8 @@ testthat::test_that("s_count_cumulative works with customized arguments", {
     thresholds = c(4, 7),
     lower_tail = FALSE,
     include_eq = FALSE,
-    na.rm = FALSE,
+    na_rm = FALSE,
+    denom = "N_col",
     .N_col = length(x)
   )
 
@@ -128,3 +129,58 @@ testthat::test_that("count_cumulative works with denom argument specified", {
   res <- testthat::expect_silent(result)
   testthat::expect_snapshot(res)
 })
+testthat::test_that("Testing label behavior when s_* forecasts label attributes", {
+  set.seed(1, kind = "Mersenne-Twister")
+  df <- data.frame(
+    a = c(sample(1:10, 10), NA),
+    type = factor(sample(c("x", "y"), 11, replace = TRUE)),
+    grp = factor(c(rep("A", 5), rep("B", 6)), levels = c("A", "B"))
+  )
+
+  result <- basic_table() %>%
+    split_cols_by("grp") %>%
+    count_cumulative(
+      vars = "a",
+      thresholds = c(3, 7),
+      show_labels = "hidden"
+    ) %>%
+    build_table(df)
+
+  testthat::expect_snapshot(row.names(result))
+
+  result <- basic_table() %>%
+    split_cols_by("grp") %>%
+    count_cumulative(
+      vars = "a",
+      thresholds = c(3, 7),
+      show_labels = "hidden",
+      .labels = c("3" = "argh")
+    ) %>%
+    build_table(df)
+
+  testthat::expect_snapshot(row.names(result))
+
+  result <- basic_table() %>%
+    split_cols_by("grp") %>%
+    count_cumulative(
+      vars = "a",
+      thresholds = c(3, 7),
+      show_labels = "hidden",
+      .stats = c("count_fraction",
+        "my_output" = function(x, ...) {
+          out <- list("a" = 1, "b" = 3)
+          attr(out, "label") <- "stat_function decides"
+          out
+        },
+        "my_output2" = function(x, ...) {
+          out <- list("min-max" = c("min" = 1, "max" = 2))
+          attr(out, "label") <- "stat_function is great"
+          out
+        }
+      )
+    ) %>%
+    build_table(df)
+
+  res <- testthat::expect_silent(result)
+  testthat::expect_snapshot(res)
+})
